## Summary

<!-- Brief description of what this PR does -->

## Type of Change

- [ ] Bug fix
- [ ] New feature
- [ ] Refactoring (no functional changes)
- [ ] Documentation
- [ ] CI / Build
- [ ] Other (describe below)

## Related Issues

<!-- Link to related issues: Fixes #123, Closes #456 -->

## Checklist

- [ ] I have tested my changes locally
- [ ] I have added/updated tests as needed
- [ ] CI passes (`pytest`, `ruff check`)
- [ ] I have updated documentation if needed
